const {
  SIGNATURE_VERSION_1_0,
  SIGNATURE_METHOD_HMAC_SHA256,
  KSMS_HOST,
  KSMS_SERVICE_NAME, 
  KSMS_VERSION
} = require('./public/constant');
const { sendPostRequest, sendGetRequest, isEmpty} = require('./public/utils');

class KsmsApi {
  constructor(accessKey, secretKey) {
    this.accessKey = accessKey;
    this.secretKey = secretKey;
  }

  buildSystemParams(action) {
    return {
      Accesskey: this.accessKey,
      Service: KSMS_SERVICE_NAME,
      Action: action,
      Version: KSMS_VERSION,
      Timestamp: new Date().toISOString().split('.')[0] + 'Z',
      SignatureVersion: SIGNATURE_VERSION_1_0,
      SignatureMethod: SIGNATURE_METHOD_HMAC_SHA256
    }
  }

  sendSms(mobile, signName, tplId, tplParams, content, smsType, extId) {
    let data = {
      Mobile: mobile,
      SignName: signName,
      ...this.buildSystemParams('SendSms')
    }

    if (
      !isEmpty(content) && !isEmpty(smsType)
    ) {
      data.Content = content;
      data.SmsType = smsType;
    }
    else {
      data.TplId = tplId;
      data.TplParams = JSON.stringify(tplParams);
    }

    if (!isEmpty(extId)) {
      data.ExtId = extId;
    }

    return sendPostRequest(KSMS_HOST, data, this.secretKey);
  }

  batchSendSms(mobile, signName, tplId, tplParams, content, smsType, extId) {
    let data = {
      Mobile: mobile,
      SignName: signName,
      ...this.buildSystemParams('BatchSendSms')
    }

    if (
      !isEmpty(content) && !isEmpty(smsType)
    ) {
      data.Content = content;
      data.SmsType = smsType;
    }
    else {
      data.TplId = tplId;
      data.TplParams = JSON.stringify(tplParams);
    }

    if (!isEmpty(extId)) {
      data.ExtId = extId;
    }

    return sendPostRequest(KSMS_HOST, data, this.secretKey);
  }

  pullSmsReport(size) {
    let data = this.buildSystemParams('PullSmsReport');
    
    if (!isEmpty(size)) {
      data.Size = size;
    }

    return sendGetRequest(KSMS_HOST, data, this.secretKey);
  }

  pullSmsUp(size) {
    let data = this.buildSystemParams('PullSmsUp');

    if (!isEmpty(size)) {
      data.Size = size;
    }

    return sendGetRequest(KSMS_HOST, data, this.secretKey);
	}
}

module.exports = KsmsApi;