const crypto = require('crypto');
const querystring = require('querystring');
const axios = require('axios');

function generateSign(params, secretKey) {
  const paramsKeyArr = Object.keys(params).sort();
  const encodedParamsStr = paramsKeyArr.reduce((total, key, index) => {
    return `${total}${key}=${encodeURIComponent(params[key])}${index === paramsKeyArr.length - 1 ? '' : '&'}`;
  }, '');

  return crypto.createHmac('sha256', secretKey).update(encodedParamsStr).digest('hex');
}

function sendPostRequest(url, data, secretKey) {
  return axios.post(url, querystring.encode({
    ...data,
    Signature: generateSign(data, secretKey)
  }));
}

function sendGetRequest(url, data, secretKey) {
  return axios.get(url, { 
    params: {
      ...data,
      Signature: generateSign(data, secretKey)
    }
  });
}

module.exports = {
  generateSign,
  sendPostRequest,
  sendGetRequest
}