const crypto = require('crypto');
const querystring = require('querystring');
const axios = require('axios');
const qs = require('qs');

function generateSign(params, secretKey) {
  const paramsKeyArr = Object.keys(params).sort();
  const newParams = {};
  for (const key of paramsKeyArr) {
    newParams[key] = params[key]
  }
  const encodedParamsStr = qs.stringify(newParams);
  return crypto.createHmac('sha256', secretKey).update(encodedParamsStr).digest('hex');
}

function sendPostRequest(url, data, secretKey) {
  return axios.post(url, querystring.encode({
    ...data,
    Signature: generateSign(data, secretKey)
  }));
}

function sendGetRequest(url, data, secretKey) {
  return axios.get(url, { 
    params: {
      ...data,
      Signature: generateSign(data, secretKey)
    }
  });
}

function isEmpty (str){
  return (str===null || str===undefined || str==='');
}

module.exports = {
  generateSign,
  sendPostRequest,
  sendGetRequest,
  isEmpty
}