// 使用前需要先npm安装axios（npm install axios --save）
const { KsmsApi } = require('../index');

const accessKey = 'xxxx';
const secretKey = 'xxxx';
const mobile = 'xxx';
const signName = 'xxx';
const tplId = 'xxx';
const tplParams = {};
const content = 'xxxx';
const smsType = 1;
const extId = 'xxx';
const size = 10;

/**
 * 实例化短信api类
 * @param {string} accessKey - 用户access key
 * @param {string} secretKey - 用户secret key
 * @return {Object} 短信api类
 */
const ksmsApi = new KsmsApi(accessKey, secretKey);

/**
 * 发送单条短信
 * @param {string} mobile - 手机号。国内11位数字，例如：1xxxxxxxx；国际需要加国家代号手机号码，例如：+861xxxxxxxx
 * @param {string} signName - 签名名称
 * @param {string} tplId - 模板ID
 * @param {Object} tplParams - 模板变量参数，例如：{ "模板变量key": "模板变量值" }
 * @param {string} [extId] - 客户自定义流水号
 * 以下两个参数，金山云账号为合作账号，content和smsType参数必填，tplParams和tplId无需传值，需单独联系客服开通
 * @param {string} content - 短信内容，中英文字符，不含特殊符号【】	
 * @param {number} smsType - 类型值，1验证码，2通知，3营销类短信
 * @return {Promise} axios返回的http response
 */
ksmsApi.sendSms(mobile, signName, tplId, tplParams, content, smsType, extId).then(
  res => console.log(res), 
  err => console.log(err.response)
);

/**
 * 发送多条短信
 * @param {string} mobile - 多个国内11位数字手机号，最多200个，例如：1xxxxxxxx,1xxxxx
 * @param {string} signName - 签名名称
 * @param {string} tplId - 模板ID
 * @param {Object} tplParams - 模板变量参数，例如：{ "模板变量key": "模板变量值" }
 * @param {string} [extId] - 客户自定义流水号
 * 以下两个参数，金山云账号为合作账号，content和smsType参数必填，tplParams和tplId无需传值，需单独联系客服开通
 * @param {string} content - 短信内容，中英文字符，不含特殊符号【】	
 * @param {string} smsType - 类型值，1验证码，2通知，3营销类短信
 * @return {Promise} axios返回的http response
 */
ksmsApi.batchSendSms(mobile, signName, tplId, tplParams, content, smsType, extId).then(
  res => console.log(res), 
  err => console.log(err.response)
);

/**
 * 拉取状态报告
 * @param {number} [size = 500] - 每次拉取个数，最大500个
 * @return {Promise} axios返回的http response
 */
ksmsApi.pullSmsReport(size).then(
  res => console.log(res.data.Data), 
  err => console.log(err.response)
);

/**
 * 拉取上行短信
 * @param {number} [size = 500] - 每次拉取个数，最大500个
 * @return {Promise} axios返回的http response
 */
ksmsApi.pullSmsUp(size).then(
  res => console.log(res.data.Data), 
  err => console.log(err.response)
);