// 使用前需要先npm安装axios（npm install axios --save）
const { VoiceApi } = require('../index');

const accessKey = 'xxxx';
const secretKey = 'xxx';
const mobile = 'xxxx';
const tplId = 'xxx';
const code = 'xxx';
const tplParams = {};
const playTimes = 2;
const content = 'xxxx';
const extId = 'xxxx';

/**
 * 实例化语音消息api类
 * @param {string} accessKey - 用户access key
 * @param {string} secretKey - 用户secret key
 * @return {Object} 语音消息api类
 */
const voiceApi = new VoiceApi(accessKey, secretKey);

/**
 * 发送语音验证码
 * @param {string} mobile - 要发送的手机号，仅支持中国大陆11位数字手机号，例如：1xxxxxxxx
 * @param {string} tplId - 语音验证码模板ID，使用系统固定模板，无需自己创建
 * @param {string} code - 验证码内容，4~8位数字，例如：123456
 * @param {string} [playTimes = 2] - 语音播放次数，取值范围1~2
 * @param {string} [extId] - 客户自定义流水号，最多50个字符
 * @return {Promise} axios返回的http response
 */
voiceApi.callVerify(mobile, tplId, code, playTimes, extId).then(
  res => console.log(res), 
  err => console.log(err.response)
);

/**
 * 发送语音通知
 * @param {string} mobile - 要发送的手机号，仅支持中国大陆11位数字手机号，例如：1xxxxxxxx
 * @param {string} tplId - 语音通知模板ID
 * @param {string} tplParams - 模板变量参数，例如：{ "模板变量key": "模板变量值" }
 * @param {string} [playTimes = 1] - 语音播放次数，取值范围1~2
 * @param {string} [extId] - 客户自定义流水号，最多50个字符
 * @return {Promise} axios返回的http response
 */
voiceApi.callNotify(mobile, tplId, tplParams, playTimes, extId).then(
  res => console.log(res), 
  err => console.log(err.response)
);

/**
 * 发送自定义内容的语音通知（需单独联系客服开通）
 * @param {string} mobile - 要发送的手机号，仅支持中国大陆11位数字手机号，例如：1xxxxxxxx
 * @param {string} [playTimes = 1] - 语音播放次数，取值范围1~2
 * @param {string} [extId] - 客户自定义流水号，最多50个字符
 * @param {string} content - 自定义语音内容，中英文字符及数字，不含特殊符号，最多100个字符
 * @return {Promise} axios返回的http response
 */
voiceApi.callNotify(mobile, null, null, playTimes, extId, content).then(
  res => console.log(res), 
  err => console.log(err.response)
);