const {
  SIGNATURE_VERSION_1_0,
  SIGNATURE_METHOD_HMAC_SHA256,
  VOICE_HOST,
  VOICE_SERVICE_NAME, 
  VOICE_VERSION
} = require('./public/constant');
const { sendPostRequest, isEmpty } = require('./public/utils');

class VoiceApi {
  constructor(accessKey, secretKey) {
    this.accessKey = accessKey;
    this.secretKey = secretKey;
  }

  buildSystemParams(action) {
    return {
      Accesskey: this.accessKey,
      Service: VOICE_SERVICE_NAME,
      Action: action,
      Version: VOICE_VERSION,
      Timestamp: new Date().toISOString().split('.')[0] + 'Z',
      SignatureVersion: SIGNATURE_VERSION_1_0,
      SignatureMethod: SIGNATURE_METHOD_HMAC_SHA256
    }
  }

  callVerify(mobile, tplId, code, playTimes, extId) {
    let data = {
      Mobile: mobile,
      TplId: tplId,
      Code: code,
      ...this.buildSystemParams('CallVerify')
    }

    if (!isEmpty(playTimes)) {
      data.PlayTimes = playTimes;
    }
    if (!isEmpty(extId)) {
      data.ExtId = extId;
    }

    return sendPostRequest(VOICE_HOST, data, this.secretKey);
  }

  callNotify(mobile, tplId, tplParams, playTimes, extId, content) {
    let data = {
      Mobile: mobile,
      ...this.buildSystemParams('CallNotify')
    }

    if (!isEmpty(content)) {
      data.Content = content;
    }
    else {
      data.TplId = tplId;
      data.TplParams = JSON.stringify(tplParams);
    }

    if (!isEmpty(playTimes)) {
      data.PlayTimes = playTimes;
    }
    if (!isEmpty(extId)) {
      data.ExtId = extId;
    }

    return sendPostRequest(VOICE_HOST, data, this.secretKey);
  }
}

module.exports = VoiceApi;